Demo Docs — mosaik 2.3.1 documentation

# Demo Docs

Page Status: | Incomplete
Last Reviewed: | 2013-10-29

Contents:

Sweet Docs

- 1 reStructuredText Demonstration
  - 1.1 Examples of Syntax Constructs
- A list
  - Second list level

- TOC Tests

This is an incredibly long caption for a long menu

- Long Sticky Nav
  - Example Menu 1
  - Example Menu 2
  - Example Menu 3
  - Example Menu 4
  - Example Menu 5
  - Example Menu 6
  - Example Menu 7
  - Example Menu 8
  - Example Menu 9
  - Example Menu 10
  - Example Menu 11
  - Example Menu 12
  - Example Menu 13
  - Example Menu 14
  - Example Menu 15
  - Example Menu 16
  - Example Menu 17
  - Example Menu 18
  - Example Menu 19
  - Example Menu 20
  - Example Submenu 1
  - Example Submenu 2
- `test_py_module`

## Maaaaath!

This is a test. Here is an equation: . Here is another:

## Giant tables

Header 1 | Header 2 | Header 3 | Header 1 | Header 2 | Header 3 | Header 1 | Header 2 | Header 3 | Header 1 | Header 2 | Header 3
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
body row 1 | column 2 | column 3 | body row 1 | column 2 | column 3 | body row 1 | column 2 | column 3 | body row 1 | column 2 | column 3
body row 1 | column 2 | column 3 | body row 1 | column 2 | column 3 | body row 1 | column 2 | column 3 | body row 1 | column 2 | column 3
body row 1 | column 2 | column 3 | body row 1 | column 2 | column 3 | body row 1 | column 2 | column 3 | body row 1 | column 2 | column 3
body row 1 | column 2 | column 3 | body row 1 | column 2 | column 3 | body row 1 | column 2 | column 3 | body row 1 | column 2 | column 3

### Optional parameter args

At this point optional parameters cannot be generated from code. However, some projects will manually do it, like so:

This example comes from django-payments module docs.

class `payments.dotpay.` `DotpayProvider`(seller_id, pin[, channel=0[, lock=False], lang='pl'])

  This backend implements payments using a popular Polish gateway, Dotpay.pl.

  Due to API limitations there is no support for transferring purchased items.

  Parameters: | seller_id – Seller ID assigned by Dotpay pin – PIN assigned by Dotpay channel – Default payment channel (consult reference guide) lang – UI language lock – Whether to disable channels other than the default selected above

## Code test

    # parsed-literal test
    curl -O http://someurl/release-2.3.tar-gz

    {
    "windows": [
        {
        "panes": [
            {
            "shell_command": [
                "echo 'did you know'",
                "echo 'you can inline'"
            ]
            },
            {
            "shell_command": "echo 'single commands'"
            },
            "echo 'for panes'"
        ],
        "window_name": "long form"
        }
    ],
    "session_name": "shorthands"
    }

## Sidebar

The first hexagram is made up of six unbroken lines. These unbroken lines stand for the primal power, which is light-giving, active, strong, and of the spirit. The hexagram is consistently strong in character, and since it is without weakness, its essence is power or energy. Its image is heaven. Its energy is represented as unrestricted by any fixed conditions in space and is therefore conceived of as motion. Time is regarded as the basis of this motion. Thus the hexagram includes also the power of time and the power of persisting in time, that is, duration.

The power represented by the hexagram is to be interpreted in a dual sense in terms of its action on the universe and of its action on the world of men. In relation to the universe, the hexagram expresses the strong, creative action of the Deity. In relation to the human world, it denotes the creative action of the holy man or sage, of the ruler or leader of men, who through his power awakens and develops their higher nature.

## Code with Sidebar

     1
     2
     3
     4
     5
     6
     7
     8
     9
    10
    11
    12
    13
    14
    15
    16
    17
    18
    19
    20
    21
    22
    23
    24
    25
    26
    27
    28
    29
    30
    31
    32
    33
    34
    35
    36
    37
    38
    39
    40
    # -*- coding: utf-8 -*-
    """Test Module for sphinx_rtd_theme."""

    class Foo:

        r"""Docstring for class Foo.

        This text tests for the formatting of docstrings generated from output
        ``sphinx.ext.autodoc``. Which contain reST, but sphinx nests it in the
        ``<dl>``, and ``<dt>`` tags. Also, ``<tt>`` is used for class, method names
        and etc, but those will *always* have the ``.descname`` or
        ``.descclassname`` class.

        Normal ``<tt>`` (like the <tt> I just wrote here) needs to be shown with
        the same style as anything else with ````this type of markup````.

        It's common for programmers to give a code example inside of their
        docstring::

            from test_py_module import Foo

            myclass = Foo()
            myclass.dothismethod('with this argument')
            myclass.flush()

            print(myclass)

        Here is a link to :py:meth:`capitalize`.
        Here is a link to :py:meth:`__init__`.

        """

        #: Doc comment for class attribute Foo.bar.
        #: It can have multiple lines.
        bar = 1

        flox = 1.5   #: Doc comment for Foo.flox. One line only.

## Boxes

Tip

Equations within a note .

Note

Equations within a note .

Danger

Equations within a note .

Warning

Equations within a note .

## Inline code and references

reStructuredText is a markup language. It can use roles and declarations to turn reST into HTML.

In reST, `*hello world*` becomes `<em>hello world</em>`. This is because a library called Docutils was able to parse the reST and use a `Writer` to output it that way.

If I type ```an inline literal``` it will wrap it in `<tt>`. You can see more details on the Inline Markup on the Docutils homepage.

Also with `sphinx.ext.autodoc`, which I use in the demo, I can link to `test_py_module.test.Foo`. It will link you right my code documentation for it.

Note

Every other line in this table will have white text on a white background.
  This is bad.

Example
Thing1
Thing2
Thing3

## Emphasized lines with line numbers

    1
    2
    3
    4
    5
    def some_function():
        interesting = False
        print 'This line is highlighted.'
        print 'This one is not...'
        print '...but this one is.'

## Citation

Here I am making a citation [1], another [2] and another [3]

[1] | This is the citation I made, let’s make this extremely long so that we can tell that it doesn’t follow the normal responsive table stuff.

[2] | This citation has some `code blocks` in it, maybe some bold and italics too. Heck, lets put a link to a meta citation [3] too.

[3] | (1, 2) This citation will have two backlinks.

# Images

This is a caption for a figure.

## Download links

`This long long long long long long long long long long long long long long long download link should be blue with icon, and should wrap white-spaces`